"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class KmsCryptoKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___KmsCryptoKeyXTimeouts = KmsCryptoKeyXTimeouts

@typing_extensions.final
class KmsCryptoKeyXVersionTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    PROTECTION_LEVEL_FIELD_NUMBER: builtins.int
    algorithm: builtins.str
    protection_level: builtins.str
    def __init__(
        self,
        *,
        algorithm: builtins.str = ...,
        protection_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["algorithm", b"algorithm", "protection_level", b"protection_level"]) -> None: ...

global___KmsCryptoKeyXVersionTemplate = KmsCryptoKeyXVersionTemplate

@typing_extensions.final
class KmsCryptoKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESTROY_SCHEDULED_DURATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_ONLY_FIELD_NUMBER: builtins.int
    KEY_RING_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PURPOSE_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    SKIP_INITIAL_VERSION_CREATION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VERSION_TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    destroy_scheduled_duration: builtins.str
    id: builtins.str
    import_only: builtins.bool
    key_ring: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    purpose: builtins.str
    rotation_period: builtins.str
    skip_initial_version_creation: builtins.bool
    @property
    def timeouts(self) -> global___KmsCryptoKeyXTimeouts: ...
    @property
    def version_template(self) -> global___KmsCryptoKeyXVersionTemplate: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        destroy_scheduled_duration: builtins.str = ...,
        id: builtins.str = ...,
        import_only: builtins.bool = ...,
        key_ring: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        purpose: builtins.str = ...,
        rotation_period: builtins.str = ...,
        skip_initial_version_creation: builtins.bool = ...,
        timeouts: global___KmsCryptoKeyXTimeouts | None = ...,
        version_template: global___KmsCryptoKeyXVersionTemplate | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts", "version_template", b"version_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destroy_scheduled_duration", b"destroy_scheduled_duration", "id", b"id", "import_only", b"import_only", "key_ring", b"key_ring", "labels", b"labels", "name", b"name", "purpose", b"purpose", "resource_info", b"resource_info", "rotation_period", b"rotation_period", "skip_initial_version_creation", b"skip_initial_version_creation", "timeouts", b"timeouts", "version_template", b"version_template"]) -> None: ...

global___KmsCryptoKey = KmsCryptoKey

@typing_extensions.final
class KmsCryptoKeyIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___KmsCryptoKeyIamBindingXCondition = KmsCryptoKeyIamBindingXCondition

@typing_extensions.final
class KmsCryptoKeyIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRYPTO_KEY_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    crypto_key_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___KmsCryptoKeyIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        crypto_key_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___KmsCryptoKeyIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "crypto_key_id", b"crypto_key_id", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___KmsCryptoKeyIamBinding = KmsCryptoKeyIamBinding

@typing_extensions.final
class KmsCryptoKeyIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___KmsCryptoKeyIamMemberXCondition = KmsCryptoKeyIamMemberXCondition

@typing_extensions.final
class KmsCryptoKeyIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRYPTO_KEY_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    crypto_key_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___KmsCryptoKeyIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        crypto_key_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___KmsCryptoKeyIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "crypto_key_id", b"crypto_key_id", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___KmsCryptoKeyIamMember = KmsCryptoKeyIamMember

@typing_extensions.final
class KmsCryptoKeyIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRYPTO_KEY_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    crypto_key_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        crypto_key_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["crypto_key_id", b"crypto_key_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___KmsCryptoKeyIamPolicy = KmsCryptoKeyIamPolicy

@typing_extensions.final
class KmsKeyRingXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___KmsKeyRingXTimeouts = KmsKeyRingXTimeouts

@typing_extensions.final
class KmsKeyRing(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def timeouts(self) -> global___KmsKeyRingXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        timeouts: global___KmsKeyRingXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___KmsKeyRing = KmsKeyRing

@typing_extensions.final
class KmsKeyRingIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___KmsKeyRingIamBindingXCondition = KmsKeyRingIamBindingXCondition

@typing_extensions.final
class KmsKeyRingIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_RING_ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    key_ring_id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___KmsKeyRingIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        key_ring_id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___KmsKeyRingIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "key_ring_id", b"key_ring_id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___KmsKeyRingIamBinding = KmsKeyRingIamBinding

@typing_extensions.final
class KmsKeyRingIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___KmsKeyRingIamMemberXCondition = KmsKeyRingIamMemberXCondition

@typing_extensions.final
class KmsKeyRingIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_RING_ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    key_ring_id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___KmsKeyRingIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        key_ring_id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___KmsKeyRingIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "key_ring_id", b"key_ring_id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___KmsKeyRingIamMember = KmsKeyRingIamMember

@typing_extensions.final
class KmsKeyRingIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_RING_ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    key_ring_id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        key_ring_id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "key_ring_id", b"key_ring_id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___KmsKeyRingIamPolicy = KmsKeyRingIamPolicy

@typing_extensions.final
class KmsKeyRingImportJobXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___KmsKeyRingImportJobXTimeouts = KmsKeyRingImportJobXTimeouts

@typing_extensions.final
class KmsKeyRingImportJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttestationEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PublicKeyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTESTATION_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IMPORT_JOB_ID_FIELD_NUMBER: builtins.int
    IMPORT_METHOD_FIELD_NUMBER: builtins.int
    KEY_RING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROTECTION_LEVEL_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def attestation(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    expire_time: builtins.str
    id: builtins.str
    import_job_id: builtins.str
    import_method: builtins.str
    key_ring: builtins.str
    name: builtins.str
    protection_level: builtins.str
    @property
    def public_key(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    state: builtins.str
    @property
    def timeouts(self) -> global___KmsKeyRingImportJobXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attestation: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        expire_time: builtins.str = ...,
        id: builtins.str = ...,
        import_job_id: builtins.str = ...,
        import_method: builtins.str = ...,
        key_ring: builtins.str = ...,
        name: builtins.str = ...,
        protection_level: builtins.str = ...,
        public_key: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        state: builtins.str = ...,
        timeouts: global___KmsKeyRingImportJobXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attestation", b"attestation", "expire_time", b"expire_time", "id", b"id", "import_job_id", b"import_job_id", "import_method", b"import_method", "key_ring", b"key_ring", "name", b"name", "protection_level", b"protection_level", "public_key", b"public_key", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts"]) -> None: ...

global___KmsKeyRingImportJob = KmsKeyRingImportJob

@typing_extensions.final
class KmsSecretCiphertextXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___KmsSecretCiphertextXTimeouts = KmsSecretCiphertextXTimeouts

@typing_extensions.final
class KmsSecretCiphertext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_AUTHENTICATED_DATA_FIELD_NUMBER: builtins.int
    CIPHERTEXT_FIELD_NUMBER: builtins.int
    CRYPTO_KEY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PLAINTEXT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    additional_authenticated_data: builtins.str
    ciphertext: builtins.str
    crypto_key: builtins.str
    id: builtins.str
    plaintext: builtins.str
    @property
    def timeouts(self) -> global___KmsSecretCiphertextXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        additional_authenticated_data: builtins.str = ...,
        ciphertext: builtins.str = ...,
        crypto_key: builtins.str = ...,
        id: builtins.str = ...,
        plaintext: builtins.str = ...,
        timeouts: global___KmsSecretCiphertextXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_authenticated_data", b"additional_authenticated_data", "ciphertext", b"ciphertext", "crypto_key", b"crypto_key", "id", b"id", "plaintext", b"plaintext", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___KmsSecretCiphertext = KmsSecretCiphertext



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DomainMasterUserOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MASTER_USER_ARN_FIELD_NUMBER: builtins.int
    MASTER_USER_NAME_FIELD_NUMBER: builtins.int
    MASTER_USER_PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    master_user_arn: builtins.str
    master_user_name: builtins.str
    master_user_password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        master_user_arn: builtins.str = ...,
        master_user_name: builtins.str = ...,
        master_user_password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["master_user_arn", b"master_user_arn", "master_user_name", b"master_user_name", "master_user_password", b"master_user_password", "resource_info", b"resource_info"]) -> None: ...

global___DomainMasterUserOptions = DomainMasterUserOptions

@typing_extensions.final
class DomainAdvancedSecurityOptionsInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    INTERNAL_USER_DATABASE_ENABLED_FIELD_NUMBER: builtins.int
    MASTER_USER_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    internal_user_database_enabled: builtins.bool
    @property
    def master_user_options(self) -> global___DomainMasterUserOptions: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        internal_user_database_enabled: builtins.bool = ...,
        master_user_options: global___DomainMasterUserOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["master_user_options", b"master_user_options", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "internal_user_database_enabled", b"internal_user_database_enabled", "master_user_options", b"master_user_options", "resource_info", b"resource_info"]) -> None: ...

global___DomainAdvancedSecurityOptionsInput = DomainAdvancedSecurityOptionsInput

@typing_extensions.final
class DomainCognitoOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    IDENTITY_POOL_ID_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    USER_POOL_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    identity_pool_id: builtins.str
    role_arn: builtins.str
    user_pool_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        identity_pool_id: builtins.str = ...,
        role_arn: builtins.str = ...,
        user_pool_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "identity_pool_id", b"identity_pool_id", "resource_info", b"resource_info", "role_arn", b"role_arn", "user_pool_id", b"user_pool_id"]) -> None: ...

global___DomainCognitoOptions = DomainCognitoOptions

@typing_extensions.final
class DomainDomainEndpointOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENFORCE_HTTP_S_FIELD_NUMBER: builtins.int
    TLS_SECURITY_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enforce_http_s: builtins.bool
    tls_security_policy: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enforce_http_s: builtins.bool = ...,
        tls_security_policy: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enforce_http_s", b"enforce_http_s", "resource_info", b"resource_info", "tls_security_policy", b"tls_security_policy"]) -> None: ...

global___DomainDomainEndpointOptions = DomainDomainEndpointOptions

@typing_extensions.final
class DomainEBSOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_ENABLED_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ebs_enabled: builtins.bool
    iops: builtins.int
    volume_size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs_enabled: builtins.bool = ...,
        iops: builtins.int = ...,
        volume_size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ebs_enabled", b"ebs_enabled", "iops", b"iops", "resource_info", b"resource_info", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___DomainEBSOptions = DomainEBSOptions

@typing_extensions.final
class DomainZoneAwarenessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    availability_zone_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        availability_zone_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone_count", b"availability_zone_count", "resource_info", b"resource_info"]) -> None: ...

global___DomainZoneAwarenessConfig = DomainZoneAwarenessConfig

@typing_extensions.final
class DomainElasticsearchClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEDICATED_MASTER_COUNT_FIELD_NUMBER: builtins.int
    DEDICATED_MASTER_ENABLED_FIELD_NUMBER: builtins.int
    DEDICATED_MASTER_TYPE_FIELD_NUMBER: builtins.int
    INSTANCE_COUNT_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    ZONE_AWARENESS_CONFIG_FIELD_NUMBER: builtins.int
    ZONE_AWARENESS_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    dedicated_master_count: builtins.int
    dedicated_master_enabled: builtins.bool
    dedicated_master_type: builtins.str
    instance_count: builtins.int
    instance_type: builtins.str
    @property
    def zone_awareness_config(self) -> global___DomainZoneAwarenessConfig: ...
    zone_awareness_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dedicated_master_count: builtins.int = ...,
        dedicated_master_enabled: builtins.bool = ...,
        dedicated_master_type: builtins.str = ...,
        instance_count: builtins.int = ...,
        instance_type: builtins.str = ...,
        zone_awareness_config: global___DomainZoneAwarenessConfig | None = ...,
        zone_awareness_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "zone_awareness_config", b"zone_awareness_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dedicated_master_count", b"dedicated_master_count", "dedicated_master_enabled", b"dedicated_master_enabled", "dedicated_master_type", b"dedicated_master_type", "instance_count", b"instance_count", "instance_type", b"instance_type", "resource_info", b"resource_info", "zone_awareness_config", b"zone_awareness_config", "zone_awareness_enabled", b"zone_awareness_enabled"]) -> None: ...

global___DomainElasticsearchClusterConfig = DomainElasticsearchClusterConfig

@typing_extensions.final
class DomainEncryptionAtRestOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    kms_key_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        kms_key_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info"]) -> None: ...

global___DomainEncryptionAtRestOptions = DomainEncryptionAtRestOptions

@typing_extensions.final
class DomainNodeToNodeEncryptionOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___DomainNodeToNodeEncryptionOptions = DomainNodeToNodeEncryptionOptions

@typing_extensions.final
class DomainSnapshotOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTOMATED_SNAPSHOT_START_HOUR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    automated_snapshot_start_hour: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        automated_snapshot_start_hour: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["automated_snapshot_start_hour", b"automated_snapshot_start_hour", "resource_info", b"resource_info"]) -> None: ...

global___DomainSnapshotOptions = DomainSnapshotOptions

@typing_extensions.final
class DomainVPCOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___DomainVPCOptions = DomainVPCOptions

@typing_extensions.final
class Domain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AccessPoliciesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class AdvancedOptionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCESS_POLICIES_FIELD_NUMBER: builtins.int
    ADVANCED_OPTIONS_FIELD_NUMBER: builtins.int
    ADVANCED_SECURITY_OPTIONS_FIELD_NUMBER: builtins.int
    COGNITO_OPTIONS_FIELD_NUMBER: builtins.int
    DOMAIN_ENDPOINT_OPTIONS_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    EBS_OPTIONS_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    ELASTICSEARCH_VERSION_FIELD_NUMBER: builtins.int
    ENCRYPTION_AT_REST_OPTIONS_FIELD_NUMBER: builtins.int
    NODE_TO_NODE_ENCRYPTION_OPTIONS_FIELD_NUMBER: builtins.int
    SNAPSHOT_OPTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_OPTIONS_FIELD_NUMBER: builtins.int
    LOG_PUBLISHING_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def access_policies(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def advanced_options(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def advanced_security_options(self) -> global___DomainAdvancedSecurityOptionsInput: ...
    @property
    def cognito_options(self) -> global___DomainCognitoOptions: ...
    @property
    def domain_endpoint_options(self) -> global___DomainDomainEndpointOptions: ...
    domain_name: builtins.str
    @property
    def ebs_options(self) -> global___DomainEBSOptions: ...
    @property
    def elasticsearch_cluster_config(self) -> global___DomainElasticsearchClusterConfig: ...
    elasticsearch_version: builtins.str
    @property
    def encryption_at_rest_options(self) -> global___DomainEncryptionAtRestOptions: ...
    @property
    def node_to_node_encryption_options(self) -> global___DomainNodeToNodeEncryptionOptions: ...
    @property
    def snapshot_options(self) -> global___DomainSnapshotOptions: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vpc_options(self) -> global___DomainVPCOptions: ...
    @property
    def log_publishing_options(self) -> global___LogPublishingOptions: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        access_policies: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        advanced_options: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        advanced_security_options: global___DomainAdvancedSecurityOptionsInput | None = ...,
        cognito_options: global___DomainCognitoOptions | None = ...,
        domain_endpoint_options: global___DomainDomainEndpointOptions | None = ...,
        domain_name: builtins.str = ...,
        ebs_options: global___DomainEBSOptions | None = ...,
        elasticsearch_cluster_config: global___DomainElasticsearchClusterConfig | None = ...,
        elasticsearch_version: builtins.str = ...,
        encryption_at_rest_options: global___DomainEncryptionAtRestOptions | None = ...,
        node_to_node_encryption_options: global___DomainNodeToNodeEncryptionOptions | None = ...,
        snapshot_options: global___DomainSnapshotOptions | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_options: global___DomainVPCOptions | None = ...,
        log_publishing_options: global___LogPublishingOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_security_options", b"advanced_security_options", "cognito_options", b"cognito_options", "domain_endpoint_options", b"domain_endpoint_options", "ebs_options", b"ebs_options", "elasticsearch_cluster_config", b"elasticsearch_cluster_config", "encryption_at_rest_options", b"encryption_at_rest_options", "log_publishing_options", b"log_publishing_options", "node_to_node_encryption_options", b"node_to_node_encryption_options", "resource_info", b"resource_info", "snapshot_options", b"snapshot_options", "vpc_options", b"vpc_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_policies", b"access_policies", "advanced_options", b"advanced_options", "advanced_security_options", b"advanced_security_options", "cognito_options", b"cognito_options", "domain_endpoint_options", b"domain_endpoint_options", "domain_name", b"domain_name", "ebs_options", b"ebs_options", "elasticsearch_cluster_config", b"elasticsearch_cluster_config", "elasticsearch_version", b"elasticsearch_version", "encryption_at_rest_options", b"encryption_at_rest_options", "log_publishing_options", b"log_publishing_options", "node_to_node_encryption_options", b"node_to_node_encryption_options", "resource_info", b"resource_info", "snapshot_options", b"snapshot_options", "tags", b"tags", "vpc_options", b"vpc_options"]) -> None: ...

global___Domain = Domain

@typing_extensions.final
class Elasticsearch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    @property
    def domain(self) -> global___Domain: ...
    def __init__(
        self,
        *,
        domain: global___Domain | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["domain", b"domain"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain"]) -> None: ...

global___Elasticsearch = Elasticsearch

@typing_extensions.final
class LogPublishingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    CLOUDWATCHLOGS_LOG_GROUP_ARN_FIELD_NUMBER: builtins.int
    LOG_TYPE_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    cloudwatchlogs_log_group_arn: builtins.str
    log_type: builtins.str
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        cloudwatchlogs_log_group_arn: builtins.str = ...,
        log_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloudwatchlogs_log_group_arn", b"cloudwatchlogs_log_group_arn", "enabled", b"enabled", "log_type", b"log_type"]) -> None: ...

global___LogPublishingOptions = LogPublishingOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_app_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleAppEngine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APP_ENGINE_APPLICATION_FIELD_NUMBER: builtins.int
    APP_ENGINE_APPLICATION_URL_DISPATCH_RULES_FIELD_NUMBER: builtins.int
    APP_ENGINE_DOMAIN_MAPPING_FIELD_NUMBER: builtins.int
    APP_ENGINE_FIREWALL_RULE_FIELD_NUMBER: builtins.int
    APP_ENGINE_FLEXIBLE_APP_VERSION_FIELD_NUMBER: builtins.int
    APP_ENGINE_SERVICE_NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    APP_ENGINE_SERVICE_SPLIT_TRAFFIC_FIELD_NUMBER: builtins.int
    APP_ENGINE_STANDARD_APP_VERSION_FIELD_NUMBER: builtins.int
    @property
    def app_engine_application(self) -> gcp.gcp_app_pb2.AppEngineApplication: ...
    @property
    def app_engine_application_url_dispatch_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineApplicationUrlDispatchRules]: ...
    @property
    def app_engine_domain_mapping(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineDomainMapping]: ...
    @property
    def app_engine_firewall_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineFirewallRule]: ...
    @property
    def app_engine_flexible_app_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineFlexibleAppVersion]: ...
    @property
    def app_engine_service_network_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineServiceNetworkSettings]: ...
    @property
    def app_engine_service_split_traffic(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineServiceSplitTraffic]: ...
    @property
    def app_engine_standard_app_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_app_pb2.AppEngineStandardAppVersion]: ...
    def __init__(
        self,
        *,
        app_engine_application: gcp.gcp_app_pb2.AppEngineApplication | None = ...,
        app_engine_application_url_dispatch_rules: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineApplicationUrlDispatchRules] | None = ...,
        app_engine_domain_mapping: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineDomainMapping] | None = ...,
        app_engine_firewall_rule: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineFirewallRule] | None = ...,
        app_engine_flexible_app_version: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineFlexibleAppVersion] | None = ...,
        app_engine_service_network_settings: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineServiceNetworkSettings] | None = ...,
        app_engine_service_split_traffic: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineServiceSplitTraffic] | None = ...,
        app_engine_standard_app_version: collections.abc.Iterable[gcp.gcp_app_pb2.AppEngineStandardAppVersion] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["app_engine_application", b"app_engine_application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_engine_application", b"app_engine_application", "app_engine_application_url_dispatch_rules", b"app_engine_application_url_dispatch_rules", "app_engine_domain_mapping", b"app_engine_domain_mapping", "app_engine_firewall_rule", b"app_engine_firewall_rule", "app_engine_flexible_app_version", b"app_engine_flexible_app_version", "app_engine_service_network_settings", b"app_engine_service_network_settings", "app_engine_service_split_traffic", b"app_engine_service_split_traffic", "app_engine_standard_app_version", b"app_engine_standard_app_version"]) -> None: ...

global___GoogleAppEngine = GoogleAppEngine



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gcp/gcp_network.proto\x12\x17oak9.tython.gcp.network\x1a\x13shared/shared.proto\"Q\n\x1fNetworkConnectivityHubXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb1\x04\n\x16NetworkConnectivityHub\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12K\n\x06labels\x18\x04 \x03(\x0b\x32;.oak9.tython.gcp.network.NetworkConnectivityHub.LabelsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12V\n\x0crouting_vpcs\x18\x07 \x03(\x0b\x32@.oak9.tython.gcp.network.NetworkConnectivityHub.RoutingVpcsEntry\x12\r\n\x05state\x18\x08 \x01(\t\x12\x11\n\tunique_id\x18\t \x01(\t\x12\x13\n\x0bupdate_time\x18\n \x01(\t\x12J\n\x08timeouts\x18\x0b \x01(\x0b\x32\x38.oak9.tython.gcp.network.NetworkConnectivityHubXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10RoutingVpcsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n6NetworkConnectivitySpokeXLinkedInterconnectAttachments\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12\x0c\n\x04uris\x18\x02 \x03(\t\"p\nANetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x17\n\x0fvirtual_machine\x18\x02 \x01(\t\"\xcc\x01\n7NetworkConnectivitySpokeXLinkedRouterApplianceInstances\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12m\n\tinstances\x18\x02 \x03(\x0b\x32Z.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances\"]\n)NetworkConnectivitySpokeXLinkedVpnTunnels\x12\"\n\x1asite_to_site_data_transfer\x18\x01 \x01(\x08\x12\x0c\n\x04uris\x18\x02 \x03(\t\"S\n!NetworkConnectivitySpokeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa1\x06\n\x18NetworkConnectivitySpoke\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03hub\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12M\n\x06labels\x18\x05 \x03(\x0b\x32=.oak9.tython.gcp.network.NetworkConnectivitySpoke.LabelsEntry\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x11\n\tunique_id\x18\n \x01(\t\x12\x13\n\x0bupdate_time\x18\x0b \x01(\t\x12x\n\x1flinked_interconnect_attachments\x18\x0c \x01(\x0b\x32O.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedInterconnectAttachments\x12{\n!linked_router_appliance_instances\x18\r \x01(\x0b\x32P.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedRouterApplianceInstances\x12^\n\x12linked_vpn_tunnels\x18\x0e \x01(\x0b\x32\x42.oak9.tython.gcp.network.NetworkConnectivitySpokeXLinkedVpnTunnels\x12L\n\x08timeouts\x18\x0f \x01(\x0b\x32:.oak9.tython.gcp.network.NetworkConnectivitySpokeXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n-NetworkManagementConnectivityTestXDestination\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x01\x12\x12\n\nproject_id\x18\x05 \x01(\t\"\x99\x01\n(NetworkManagementConnectivityTestXSource\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x14\n\x0cnetwork_type\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x12\n\nproject_id\x18\x06 \x01(\t\"\\\n*NetworkManagementConnectivityTestXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd6\x04\n!NetworkManagementConnectivityTest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.oak9.tython.gcp.network.NetworkManagementConnectivityTest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x10\n\x08protocol\x18\x06 \x01(\t\x12\x18\n\x10related_projects\x18\x07 \x03(\t\x12[\n\x0b\x64\x65stination\x18\x08 \x01(\x0b\x32\x46.oak9.tython.gcp.network.NetworkManagementConnectivityTestXDestination\x12Q\n\x06source\x18\t \x01(\x0b\x32\x41.oak9.tython.gcp.network.NetworkManagementConnectivityTestXSource\x12U\n\x08timeouts\x18\n \x01(\x0b\x32\x43.oak9.tython.gcp.network.NetworkManagementConnectivityTestXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n(NetworkServicesEdgeCacheKeysetXPublicKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Y\n\'NetworkServicesEdgeCacheKeysetXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x03\n\x1eNetworkServicesEdgeCacheKeyset\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12S\n\x06labels\x18\x03 \x03(\x0b\x32\x43.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeyset.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12U\n\npublic_key\x18\x06 \x03(\x0b\x32\x41.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeysetXPublicKey\x12R\n\x08timeouts\x18\x07 \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheKeysetXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n&NetworkServicesEdgeCacheOriginXTimeout\x12\x17\n\x0f\x63onnect_timeout\x18\x01 \x01(\t\x12\x1c\n\x14max_attempts_timeout\x18\x02 \x01(\t\x12\x14\n\x0cread_timeout\x18\x03 \x01(\t\x12\x18\n\x10response_timeout\x18\x04 \x01(\t\"Y\n\'NetworkServicesEdgeCacheOriginXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc4\x04\n\x1eNetworkServicesEdgeCacheOrigin\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x61ilover_origin\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12S\n\x06labels\x18\x04 \x03(\x0b\x32\x43.oak9.tython.gcp.network.NetworkServicesEdgeCacheOrigin.LabelsEntry\x12\x14\n\x0cmax_attempts\x18\x05 \x01(\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x16\n\x0eorigin_address\x18\x07 \x01(\t\x12\x0c\n\x04port\x18\x08 \x01(\x01\x12\x0f\n\x07project\x18\t \x01(\t\x12\x10\n\x08protocol\x18\n \x01(\t\x12\x18\n\x10retry_conditions\x18\x0b \x03(\t\x12P\n\x07timeout\x18\x0c \x01(\x0b\x32?.oak9.tython.gcp.network.NetworkServicesEdgeCacheOriginXTimeout\x12R\n\x08timeouts\x18\r \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheOriginXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n)NetworkServicesEdgeCacheServiceXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"l\n0NetworkServicesEdgeCacheServiceXRoutingXHostRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x14\n\x0cpath_matcher\x18\x03 \x01(\t\"\x9b\x01\n]NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"w\n`NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"\x9c\x01\n^NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"x\naNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\"\xbc\x05\nJNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction\x12\x95\x01\n\x15request_header_to_add\x18\x01 \x03(\x0b\x32v.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd\x12\x9b\x01\n\x18request_header_to_remove\x18\x02 \x03(\x0b\x32y.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove\x12\x97\x01\n\x16response_header_to_add\x18\x03 \x03(\x0b\x32w.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd\x12\x9d\x01\n\x19response_header_to_remove\x18\x04 \x03(\x0b\x32z.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove\"\xd8\x01\nSNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x14\n\x0cinvert_match\x18\x03 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x15\n\rpresent_match\x18\x05 \x01(\x08\x12\x14\n\x0csuffix_match\x18\x06 \x01(\t\"\x97\x01\n[NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rpresent_match\x18\x03 \x01(\x08\"\xc5\x03\nGNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule\x12\x17\n\x0f\x66ull_path_match\x18\x01 \x01(\t\x12\x13\n\x0bignore_case\x18\x02 \x01(\x08\x12\x1b\n\x13path_template_match\x18\x03 \x01(\t\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x82\x01\n\x0cheader_match\x18\x05 \x03(\x0b\x32l.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch\x12\x93\x01\n\x15query_parameter_match\x18\x06 \x03(\x0b\x32t.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch\"\xb6\x02\nbNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy\x12\x14\n\x0c\x65xclude_host\x18\x01 \x01(\x08\x12\x1c\n\x14\x65xclude_query_string\x18\x02 \x01(\x08\x12!\n\x19\x65xcluded_query_parameters\x18\x03 \x03(\t\x12\x18\n\x10include_protocol\x18\x04 \x01(\x08\x12\x1d\n\x15included_cookie_names\x18\x05 \x03(\t\x12\x1d\n\x15included_header_names\x18\x06 \x03(\t\x12!\n\x19included_query_parameters\x18\x07 \x03(\t\"\xfb\x04\nSNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy\x12\x12\n\ncache_mode\x18\x01 \x01(\t\x12\x12\n\nclient_ttl\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\t\x12\x0f\n\x07max_ttl\x18\x04 \x01(\t\x12\x18\n\x10negative_caching\x18\x05 \x01(\x08\x12\xa9\x01\n\x17negative_caching_policy\x18\x06 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy.NegativeCachingPolicyEntry\x12\x1d\n\x15signed_request_keyset\x18\x07 \x01(\t\x12\x1b\n\x13signed_request_mode\x18\x08 \x01(\t\x12\x95\x01\n\x10\x63\x61\x63he_key_policy\x18\t \x01(\x0b\x32{.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy\x1a<\n\x1aNegativeCachingPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf1\x01\nTNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x15\n\rallow_origins\x18\x04 \x03(\t\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x06 \x03(\t\x12\x0f\n\x07max_age\x18\x07 \x01(\t\"\xa8\x01\nTNetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\x12\x1d\n\x15path_template_rewrite\x18\x03 \x01(\t\"\xd8\x03\nINetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction\x12\x80\x01\n\ncdn_policy\x18\x01 \x01(\x0b\x32l.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy\x12\x82\x01\n\x0b\x63ors_policy\x18\x02 \x01(\x0b\x32m.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy\x12\x82\x01\n\x0burl_rewrite\x18\x03 \x01(\x0b\x32m.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite\"\xdf\x01\nINetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xdc\x04\n=NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x10\n\x08priority\x18\x03 \x01(\t\x12z\n\rheader_action\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction\x12t\n\nmatch_rule\x18\x05 \x03(\x0b\x32`.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule\x12x\n\x0croute_action\x18\x06 \x01(\x0b\x32\x62.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction\x12x\n\x0curl_redirect\x18\x07 \x01(\x0b\x32\x62.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect\"\xc4\x01\n3NetworkServicesEdgeCacheServiceXRoutingXPathMatcher\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12j\n\nroute_rule\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule\"\xeb\x01\n\'NetworkServicesEdgeCacheServiceXRouting\x12\\\n\thost_rule\x18\x01 \x03(\x0b\x32I.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXHostRule\x12\x62\n\x0cpath_matcher\x18\x02 \x03(\x0b\x32L.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRoutingXPathMatcher\"Z\n(NetworkServicesEdgeCacheServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe2\x05\n\x1fNetworkServicesEdgeCacheService\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x15\n\rdisable_http2\x18\x02 \x01(\x08\x12\x14\n\x0c\x64isable_quic\x18\x03 \x01(\x08\x12\x1c\n\x14\x65\x64ge_security_policy\x18\x04 \x01(\t\x12\x1d\n\x15\x65\x64ge_ssl_certificates\x18\x05 \x03(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x16\n\x0eipv4_addresses\x18\x07 \x03(\t\x12\x16\n\x0eipv6_addresses\x18\x08 \x03(\t\x12T\n\x06labels\x18\t \x03(\x0b\x32\x44.oak9.tython.gcp.network.NetworkServicesEdgeCacheService.LabelsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x13\n\x0brequire_tls\x18\x0c \x01(\x08\x12\x12\n\nssl_policy\x18\r \x01(\t\x12V\n\nlog_config\x18\x0e \x01(\x0b\x32\x42.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXLogConfig\x12Q\n\x07routing\x18\x0f \x01(\x0b\x32@.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXRouting\x12S\n\x08timeouts\x18\x10 \x01(\x0b\x32\x41.oak9.tython.gcp.network.NetworkServicesEdgeCacheServiceXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._options = None
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._options = None
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._options = None
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._options = None
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._options = None
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_options = b'8\001'
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._options = None
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_options = b'8\001'
  _NETWORKCONNECTIVITYHUBXTIMEOUTS._serialized_start=71
  _NETWORKCONNECTIVITYHUBXTIMEOUTS._serialized_end=152
  _NETWORKCONNECTIVITYHUB._serialized_start=155
  _NETWORKCONNECTIVITYHUB._serialized_end=716
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_start=619
  _NETWORKCONNECTIVITYHUB_LABELSENTRY._serialized_end=664
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_start=666
  _NETWORKCONNECTIVITYHUB_ROUTINGVPCSENTRY._serialized_end=716
  _NETWORKCONNECTIVITYSPOKEXLINKEDINTERCONNECTATTACHMENTS._serialized_start=718
  _NETWORKCONNECTIVITYSPOKEXLINKEDINTERCONNECTATTACHMENTS._serialized_end=824
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCESXINSTANCES._serialized_start=826
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCESXINSTANCES._serialized_end=938
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCES._serialized_start=941
  _NETWORKCONNECTIVITYSPOKEXLINKEDROUTERAPPLIANCEINSTANCES._serialized_end=1145
  _NETWORKCONNECTIVITYSPOKEXLINKEDVPNTUNNELS._serialized_start=1147
  _NETWORKCONNECTIVITYSPOKEXLINKEDVPNTUNNELS._serialized_end=1240
  _NETWORKCONNECTIVITYSPOKEXTIMEOUTS._serialized_start=1242
  _NETWORKCONNECTIVITYSPOKEXTIMEOUTS._serialized_end=1325
  _NETWORKCONNECTIVITYSPOKE._serialized_start=1328
  _NETWORKCONNECTIVITYSPOKE._serialized_end=2129
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_start=619
  _NETWORKCONNECTIVITYSPOKE_LABELSENTRY._serialized_end=664
  _NETWORKMANAGEMENTCONNECTIVITYTESTXDESTINATION._serialized_start=2132
  _NETWORKMANAGEMENTCONNECTIVITYTESTXDESTINATION._serialized_end=2268
  _NETWORKMANAGEMENTCONNECTIVITYTESTXSOURCE._serialized_start=2271
  _NETWORKMANAGEMENTCONNECTIVITYTESTXSOURCE._serialized_end=2424
  _NETWORKMANAGEMENTCONNECTIVITYTESTXTIMEOUTS._serialized_start=2426
  _NETWORKMANAGEMENTCONNECTIVITYTESTXTIMEOUTS._serialized_end=2518
  _NETWORKMANAGEMENTCONNECTIVITYTEST._serialized_start=2521
  _NETWORKMANAGEMENTCONNECTIVITYTEST._serialized_end=3119
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_start=619
  _NETWORKMANAGEMENTCONNECTIVITYTEST_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHEKEYSETXPUBLICKEY._serialized_start=3121
  _NETWORKSERVICESEDGECACHEKEYSETXPUBLICKEY._serialized_end=3190
  _NETWORKSERVICESEDGECACHEKEYSETXTIMEOUTS._serialized_start=3192
  _NETWORKSERVICESEDGECACHEKEYSETXTIMEOUTS._serialized_end=3281
  _NETWORKSERVICESEDGECACHEKEYSET._serialized_start=3284
  _NETWORKSERVICESEDGECACHEKEYSET._serialized_end=3740
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHEKEYSET_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUT._serialized_start=3743
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUT._serialized_end=3886
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUTS._serialized_start=3888
  _NETWORKSERVICESEDGECACHEORIGINXTIMEOUTS._serialized_end=3977
  _NETWORKSERVICESEDGECACHEORIGIN._serialized_start=3980
  _NETWORKSERVICESEDGECACHEORIGIN._serialized_end=4560
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHEORIGIN_LABELSENTRY._serialized_end=664
  _NETWORKSERVICESEDGECACHESERVICEXLOGCONFIG._serialized_start=4562
  _NETWORKSERVICESEDGECACHESERVICEXLOGCONFIG._serialized_end=4642
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXHOSTRULE._serialized_start=4644
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXHOSTRULE._serialized_end=4752
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOADD._serialized_start=4755
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOADD._serialized_end=4910
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOREMOVE._serialized_start=4912
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXREQUESTHEADERTOREMOVE._serialized_end=5031
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOADD._serialized_start=5034
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOADD._serialized_end=5190
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOREMOVE._serialized_start=5192
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTIONXRESPONSEHEADERTOREMOVE._serialized_end=5312
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTION._serialized_start=5315
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXHEADERACTION._serialized_end=6015
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXHEADERMATCH._serialized_start=6018
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXHEADERMATCH._serialized_end=6234
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXQUERYPARAMETERMATCH._serialized_start=6237
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULEXQUERYPARAMETERMATCH._serialized_end=6388
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULE._serialized_start=6391
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXMATCHRULE._serialized_end=6844
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICYXCACHEKEYPOLICY._serialized_start=6847
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICYXCACHEKEYPOLICY._serialized_end=7157
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY._serialized_start=7160
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY._serialized_end=7795
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_start=7735
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCDNPOLICY_NEGATIVECACHINGPOLICYENTRY._serialized_end=7795
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCORSPOLICY._serialized_start=7798
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXCORSPOLICY._serialized_end=8039
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXURLREWRITE._serialized_start=8042
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTIONXURLREWRITE._serialized_end=8210
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTION._serialized_start=8213
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXROUTEACTION._serialized_end=8685
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXURLREDIRECT._serialized_start=8688
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULEXURLREDIRECT._serialized_end=8911
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULE._serialized_start=8914
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHERXROUTERULE._serialized_end=9518
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHER._serialized_start=9521
  _NETWORKSERVICESEDGECACHESERVICEXROUTINGXPATHMATCHER._serialized_end=9717
  _NETWORKSERVICESEDGECACHESERVICEXROUTING._serialized_start=9720
  _NETWORKSERVICESEDGECACHESERVICEXROUTING._serialized_end=9955
  _NETWORKSERVICESEDGECACHESERVICEXTIMEOUTS._serialized_start=9957
  _NETWORKSERVICESEDGECACHESERVICEXTIMEOUTS._serialized_end=10047
  _NETWORKSERVICESEDGECACHESERVICE._serialized_start=10050
  _NETWORKSERVICESEDGECACHESERVICE._serialized_end=10788
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_start=619
  _NETWORKSERVICESEDGECACHESERVICE_LABELSENTRY._serialized_end=664
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TableAttributeDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ATTRIBUTE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attribute_name: builtins.str
    attribute_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_name: builtins.str = ...,
        attribute_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_name", b"attribute_name", "attribute_type", b"attribute_type", "resource_info", b"resource_info"]) -> None: ...

global___TableAttributeDefinition = TableAttributeDefinition

@typing_extensions.final
class DynamoDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_ATTRIBUTE_DEFINITION_FIELD_NUMBER: builtins.int
    TABLE_GLOBAL_SECONDARY_INDEX_FIELD_NUMBER: builtins.int
    TABLE_LOCAL_SECONDARY_INDEX_FIELD_NUMBER: builtins.int
    TABLE_POINT_IN_TIME_RECOVERY_SPECIFICATION_FIELD_NUMBER: builtins.int
    TABLE_SSE_SPECIFICATION_FIELD_NUMBER: builtins.int
    TABLE_STREAM_SPECIFICATION_FIELD_NUMBER: builtins.int
    TABLE_TIME_TO_LIVE_SPECIFICATION_FIELD_NUMBER: builtins.int
    @property
    def table_attribute_definition(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableAttributeDefinition]: ...
    @property
    def table_global_secondary_index(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableGlobalSecondaryIndex]: ...
    @property
    def table_local_secondary_index(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableLocalSecondaryIndex]: ...
    @property
    def table_point_in_time_recovery_specification(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TablePointInTimeRecoverySpecification]: ...
    @property
    def table_sse_specification(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableSSESpecification]: ...
    @property
    def table_stream_specification(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableStreamSpecification]: ...
    @property
    def table_time_to_live_specification(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableTimeToLiveSpecification]: ...
    def __init__(
        self,
        *,
        table_attribute_definition: collections.abc.Iterable[global___TableAttributeDefinition] | None = ...,
        table_global_secondary_index: collections.abc.Iterable[global___TableGlobalSecondaryIndex] | None = ...,
        table_local_secondary_index: collections.abc.Iterable[global___TableLocalSecondaryIndex] | None = ...,
        table_point_in_time_recovery_specification: collections.abc.Iterable[global___TablePointInTimeRecoverySpecification] | None = ...,
        table_sse_specification: collections.abc.Iterable[global___TableSSESpecification] | None = ...,
        table_stream_specification: collections.abc.Iterable[global___TableStreamSpecification] | None = ...,
        table_time_to_live_specification: collections.abc.Iterable[global___TableTimeToLiveSpecification] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["table_attribute_definition", b"table_attribute_definition", "table_global_secondary_index", b"table_global_secondary_index", "table_local_secondary_index", b"table_local_secondary_index", "table_point_in_time_recovery_specification", b"table_point_in_time_recovery_specification", "table_sse_specification", b"table_sse_specification", "table_stream_specification", b"table_stream_specification", "table_time_to_live_specification", b"table_time_to_live_specification"]) -> None: ...

global___DynamoDB = DynamoDB

@typing_extensions.final
class TableKeySchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    KEY_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attribute_name: builtins.str
    key_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_name: builtins.str = ...,
        key_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_name", b"attribute_name", "key_type", b"key_type", "resource_info", b"resource_info"]) -> None: ...

global___TableKeySchema = TableKeySchema

@typing_extensions.final
class TableProjection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NON_KEY_ATTRIBUTES_FIELD_NUMBER: builtins.int
    PROJECTION_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def non_key_attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    projection_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        non_key_attributes: collections.abc.Iterable[builtins.str] | None = ...,
        projection_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["non_key_attributes", b"non_key_attributes", "projection_type", b"projection_type", "resource_info", b"resource_info"]) -> None: ...

global___TableProjection = TableProjection

@typing_extensions.final
class TableProvisionedThroughput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    READ_CAPACITY_UNITS_FIELD_NUMBER: builtins.int
    WRITE_CAPACITY_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    read_capacity_units: builtins.int
    write_capacity_units: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        read_capacity_units: builtins.int = ...,
        write_capacity_units: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["read_capacity_units", b"read_capacity_units", "resource_info", b"resource_info", "write_capacity_units", b"write_capacity_units"]) -> None: ...

global___TableProvisionedThroughput = TableProvisionedThroughput

@typing_extensions.final
class TableGlobalSecondaryIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INDEX_NAME_FIELD_NUMBER: builtins.int
    KEY_SCHEMA_FIELD_NUMBER: builtins.int
    PROJECTION_FIELD_NUMBER: builtins.int
    PROVISIONED_THROUGHPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    index_name: builtins.str
    @property
    def key_schema(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableKeySchema]: ...
    @property
    def projection(self) -> global___TableProjection: ...
    @property
    def provisioned_throughput(self) -> global___TableProvisionedThroughput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        index_name: builtins.str = ...,
        key_schema: collections.abc.Iterable[global___TableKeySchema] | None = ...,
        projection: global___TableProjection | None = ...,
        provisioned_throughput: global___TableProvisionedThroughput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["projection", b"projection", "provisioned_throughput", b"provisioned_throughput", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["index_name", b"index_name", "key_schema", b"key_schema", "projection", b"projection", "provisioned_throughput", b"provisioned_throughput", "resource_info", b"resource_info"]) -> None: ...

global___TableGlobalSecondaryIndex = TableGlobalSecondaryIndex

@typing_extensions.final
class TableLocalSecondaryIndex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INDEX_NAME_FIELD_NUMBER: builtins.int
    KEY_SCHEMA_FIELD_NUMBER: builtins.int
    PROJECTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    index_name: builtins.str
    @property
    def key_schema(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableKeySchema]: ...
    @property
    def projection(self) -> global___TableProjection: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        index_name: builtins.str = ...,
        key_schema: collections.abc.Iterable[global___TableKeySchema] | None = ...,
        projection: global___TableProjection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["projection", b"projection", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["index_name", b"index_name", "key_schema", b"key_schema", "projection", b"projection", "resource_info", b"resource_info"]) -> None: ...

global___TableLocalSecondaryIndex = TableLocalSecondaryIndex

@typing_extensions.final
class TablePointInTimeRecoverySpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POINT_IN_TIME_RECOVERY_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    point_in_time_recovery_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        point_in_time_recovery_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["point_in_time_recovery_enabled", b"point_in_time_recovery_enabled", "resource_info", b"resource_info"]) -> None: ...

global___TablePointInTimeRecoverySpecification = TablePointInTimeRecoverySpecification

@typing_extensions.final
class TableSSESpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KMS_MASTER_KEY_ID_FIELD_NUMBER: builtins.int
    SSE_ENABLED_FIELD_NUMBER: builtins.int
    SSE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    kms_master_key_id: builtins.str
    sse_enabled: builtins.bool
    sse_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        kms_master_key_id: builtins.str = ...,
        sse_enabled: builtins.bool = ...,
        sse_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_master_key_id", b"kms_master_key_id", "resource_info", b"resource_info", "sse_enabled", b"sse_enabled", "sse_type", b"sse_type"]) -> None: ...

global___TableSSESpecification = TableSSESpecification

@typing_extensions.final
class TableStreamSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STREAM_VIEW_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    stream_view_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        stream_view_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "stream_view_type", b"stream_view_type"]) -> None: ...

global___TableStreamSpecification = TableStreamSpecification

@typing_extensions.final
class TableTimeToLiveSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ATTRIBUTE_NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    attribute_name: builtins.str
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        attribute_name: builtins.str = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute_name", b"attribute_name", "enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___TableTimeToLiveSpecification = TableTimeToLiveSpecification



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_secret_manager_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_secret_pb2 as gcp_dot_gcp__secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*gcp/gcp_google_secret_manager_bundle.proto\x12,oak9.tython.gcp.google_secret_manager_bundle\x1a\x13shared/shared.proto\x1a\x14gcp/gcp_secret.proto\"\xde\x03\n\x13GoogleSecretManager\x12J\n\x15secret_manager_secret\x18\x01 \x01(\x0b\x32+.oak9.tython.gcp.secret.SecretManagerSecret\x12`\n!secret_manager_secret_iam_binding\x18\x02 \x03(\x0b\x32\x35.oak9.tython.gcp.secret.SecretManagerSecretIamBinding\x12^\n secret_manager_secret_iam_member\x18\x03 \x03(\x0b\x32\x34.oak9.tython.gcp.secret.SecretManagerSecretIamMember\x12^\n secret_manager_secret_iam_policy\x18\x04 \x03(\x0b\x32\x34.oak9.tython.gcp.secret.SecretManagerSecretIamPolicy\x12Y\n\x1dsecret_manager_secret_version\x18\x05 \x01(\x0b\x32\x32.oak9.tython.gcp.secret.SecretManagerSecretVersionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_secret_manager_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLESECRETMANAGER._serialized_start=136
  _GOOGLESECRETMANAGER._serialized_end=614
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_compute_network_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleComputeNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPUTE_NETWORK_FIELD_NUMBER: builtins.int
    COMPUTE_NETWORK_PEERING_FIELD_NUMBER: builtins.int
    COMPUTE_NETWORK_PEERING_ROUTES_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def compute_network(self) -> gcp.gcp_compute_network_pb2.ComputeNetwork: ...
    @property
    def compute_network_peering(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_network_pb2.ComputeNetworkPeering]: ...
    @property
    def compute_network_peering_routes_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_compute_network_pb2.ComputeNetworkPeeringRoutesConfig]: ...
    def __init__(
        self,
        *,
        compute_network: gcp.gcp_compute_network_pb2.ComputeNetwork | None = ...,
        compute_network_peering: collections.abc.Iterable[gcp.gcp_compute_network_pb2.ComputeNetworkPeering] | None = ...,
        compute_network_peering_routes_config: collections.abc.Iterable[gcp.gcp_compute_network_pb2.ComputeNetworkPeeringRoutesConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compute_network", b"compute_network"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compute_network", b"compute_network", "compute_network_peering", b"compute_network_peering", "compute_network_peering_routes_config", b"compute_network_peering_routes_config"]) -> None: ...

global___GoogleComputeNetwork = GoogleComputeNetwork



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.storage.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.api import resource_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_api_dot_resource__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1kubernetes/kubernetes_io.k8s.api.storage.v1.proto\x12\x1eoak9.tython.k8s.api.storage.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.api.resource.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\"\xf1\x01\n\tCSIDriver\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x04 \x01(\x0b\x32-.oak9.tython.k8s.api.storage.v1.CSIDriverSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf0\x01\n\rCSIDriverList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).oak9.tython.k8s.api.storage.v1.CSIDriver\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x02\n\rCSIDriverSpec\x12\x17\n\x0f\x61ttach_required\x18\x01 \x01(\x08\x12\x17\n\x0f\x66s_group_policy\x18\x02 \x01(\t\x12\x19\n\x11pod_info_on_mount\x18\x03 \x01(\x08\x12\x1a\n\x12requires_republish\x18\x04 \x01(\x08\x12\x16\n\x0ese_linux_mount\x18\x05 \x01(\x08\x12\x18\n\x10storage_capacity\x18\x06 \x01(\x08\x12\x44\n\x0etoken_requests\x18\x07 \x03(\x0b\x32,.oak9.tython.k8s.api.storage.v1.TokenRequest\x12\x1e\n\x16volume_lifecycle_modes\x18\x08 \x03(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\x07\x43SINode\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x39\n\x04spec\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.CSINodeSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc8\x01\n\rCSINodeDriver\x12H\n\x0b\x61llocatable\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.api.storage.v1.VolumeNodeResources\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07node_id\x18\x03 \x01(\t\x12\x15\n\rtopology_keys\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xec\x01\n\x0b\x43SINodeList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x36\n\x05items\x18\x02 \x03(\x0b\x32\'.oak9.tython.k8s.api.storage.v1.CSINode\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x86\x01\n\x0b\x43SINodeSpec\x12>\n\x07\x64rivers\x18\x01 \x03(\x0b\x32-.oak9.tython.k8s.api.storage.v1.CSINodeDriver\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcf\x03\n\x12\x43SIStorageCapacity\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12I\n\x08\x63\x61pacity\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12T\n\x13maximum_volume_size\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.api.resource.Quantity\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12S\n\rnode_topology\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x1a\n\x12storage_class_name\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x82\x02\n\x16\x43SIStorageCapacityList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x41\n\x05items\x18\x02 \x03(\x0b\x32\x32.oak9.tython.k8s.api.storage.v1.CSIStorageCapacity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8c\x04\n\x0cStorageClass\x12\x1e\n\x16\x61llow_volume_expansion\x18\x01 \x01(\x08\x12M\n\x12\x61llowed_topologies\x18\x02 \x03(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.TopologySelectorTerm\x12\x13\n\x0b\x61pi_version\x18\x03 \x01(\t\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12K\n\x08metadata\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x15\n\rmount_options\x18\x06 \x03(\t\x12P\n\nparameters\x18\x07 \x03(\x0b\x32<.oak9.tython.k8s.api.storage.v1.StorageClass.ParametersEntry\x12\x13\n\x0bprovisioner\x18\x08 \x01(\t\x12\x16\n\x0ereclaim_policy\x18\t \x01(\t\x12\x1b\n\x13volume_binding_mode\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x10StorageClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12;\n\x05items\x18\x02 \x03(\x0b\x32,.oak9.tython.k8s.api.storage.v1.StorageClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"u\n\x0cTokenRequest\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1a\n\x12\x65xpiration_seconds\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x02\n\x10VolumeAttachment\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x42\n\x04spec\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.storage.v1.VolumeAttachmentSpec\x12\x46\n\x06status\x18\x05 \x01(\x0b\x32\x36.oak9.tython.k8s.api.storage.v1.VolumeAttachmentStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfe\x01\n\x14VolumeAttachmentList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12?\n\x05items\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.storage.v1.VolumeAttachment\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc0\x01\n\x16VolumeAttachmentSource\x12M\n\x12inline_volume_spec\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.core.v1.PersistentVolumeSpec\x12\x1e\n\x16persistent_volume_name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n\x14VolumeAttachmentSpec\x12\x10\n\x08\x61ttacher\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x46\n\x06source\x18\x03 \x01(\x0b\x32\x36.oak9.tython.k8s.api.storage.v1.VolumeAttachmentSource\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x91\x03\n\x16VolumeAttachmentStatus\x12\x41\n\x0c\x61ttach_error\x18\x01 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.VolumeError\x12\x10\n\x08\x61ttached\x18\x02 \x01(\x08\x12k\n\x13\x61ttachment_metadata\x18\x03 \x03(\x0b\x32N.oak9.tython.k8s.api.storage.v1.VolumeAttachmentStatus.AttachmentMetadataEntry\x12\x41\n\x0c\x64\x65tach_error\x18\x04 \x01(\x0b\x32+.oak9.tython.k8s.api.storage.v1.VolumeError\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x39\n\x17\x41ttachmentMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9a\x01\n\x0bVolumeError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x41\n\x04time\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n\x13VolumeNodeResources\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.storage.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGECLASS_PARAMETERSENTRY._options = None
  _STORAGECLASS_PARAMETERSENTRY._serialized_options = b'8\001'
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._options = None
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_options = b'8\001'
  _CSIDRIVER._serialized_start=287
  _CSIDRIVER._serialized_end=528
  _CSIDRIVERLIST._serialized_start=531
  _CSIDRIVERLIST._serialized_end=771
  _CSIDRIVERSPEC._serialized_start=774
  _CSIDRIVERSPEC._serialized_end=1103
  _CSINODE._serialized_start=1106
  _CSINODE._serialized_end=1343
  _CSINODEDRIVER._serialized_start=1346
  _CSINODEDRIVER._serialized_end=1546
  _CSINODELIST._serialized_start=1549
  _CSINODELIST._serialized_end=1785
  _CSINODESPEC._serialized_start=1788
  _CSINODESPEC._serialized_end=1922
  _CSISTORAGECAPACITY._serialized_start=1925
  _CSISTORAGECAPACITY._serialized_end=2388
  _CSISTORAGECAPACITYLIST._serialized_start=2391
  _CSISTORAGECAPACITYLIST._serialized_end=2649
  _STORAGECLASS._serialized_start=2652
  _STORAGECLASS._serialized_end=3176
  _STORAGECLASS_PARAMETERSENTRY._serialized_start=3127
  _STORAGECLASS_PARAMETERSENTRY._serialized_end=3176
  _STORAGECLASSLIST._serialized_start=3179
  _STORAGECLASSLIST._serialized_end=3425
  _TOKENREQUEST._serialized_start=3427
  _TOKENREQUEST._serialized_end=3544
  _VOLUMEATTACHMENT._serialized_start=3547
  _VOLUMEATTACHMENT._serialized_end=3874
  _VOLUMEATTACHMENTLIST._serialized_start=3877
  _VOLUMEATTACHMENTLIST._serialized_end=4131
  _VOLUMEATTACHMENTSOURCE._serialized_start=4134
  _VOLUMEATTACHMENTSOURCE._serialized_end=4326
  _VOLUMEATTACHMENTSPEC._serialized_start=4329
  _VOLUMEATTACHMENTSPEC._serialized_end=4517
  _VOLUMEATTACHMENTSTATUS._serialized_start=4520
  _VOLUMEATTACHMENTSTATUS._serialized_end=4921
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_start=4864
  _VOLUMEATTACHMENTSTATUS_ATTACHMENTMETADATAENTRY._serialized_end=4921
  _VOLUMEERROR._serialized_start=4924
  _VOLUMEERROR._serialized_end=5078
  _VOLUMENODERESOURCES._serialized_start=5080
  _VOLUMENODERESOURCES._serialized_end=5173
# @@protoc_insertion_point(module_scope)
